"""add column on type_field_association

Revision ID: f97ed2cdfb29
Revises: 8e3f13ce98cb
Create Date: 2021-11-05 11:05:37.683957

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'f97ed2cdfb29'
down_revision = '8e3f13ce98cb'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('type_field_association', schema=None) as batch_op:
        batch_op.add_column(sa.Column('order', sa.Integer(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('type_field_association', schema=None) as batch_op:
        batch_op.drop_column('order')

    # ### end Alembic commands ###
