"""add three columns to product_relation_types

Revision ID: 0f7fd06aa729
Revises: 0cce33011766
Create Date: 2020-05-25 20:12:35.109293

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '0f7fd06aa729'
down_revision = '0cce33011766'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('product_relation_types', schema=None) as batch_op:
        batch_op.add_column(sa.Column('indef_article', sa.Text(), nullable=True))
        batch_op.add_column(sa.Column('plural', sa.Text(), nullable=True))
        batch_op.add_column(sa.Column('singular', sa.Text(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('product_relation_types', schema=None) as batch_op:
        batch_op.drop_column('singular')
        batch_op.drop_column('plural')
        batch_op.drop_column('indef_article')

    # ### end Alembic commands ###
