"""remove columns from products

Revision ID: 2ed9841987be
Revises: f97ed2cdfb29
Create Date: 2021-11-19 11:20:57.432203

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '2ed9841987be'
down_revision = 'f97ed2cdfb29'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('products', schema=None) as batch_op:
        batch_op.drop_column('posted_by')
        batch_op.drop_column('produced_by')
        batch_op.drop_column('updated_by')
        batch_op.drop_column('contact')
        batch_op.drop_column('date_produced')

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('products', schema=None) as batch_op:
        batch_op.add_column(sa.Column('date_produced', sa.DATE(), nullable=True))
        batch_op.add_column(sa.Column('contact', sa.TEXT(), nullable=True))
        batch_op.add_column(sa.Column('updated_by', sa.TEXT(), nullable=True))
        batch_op.add_column(sa.Column('produced_by', sa.TEXT(), nullable=True))
        batch_op.add_column(sa.Column('posted_by', sa.TEXT(), nullable=True))

    # ### end Alembic commands ###
