"""add a table admin_app_token

Revision ID: d5e539d43045
Revises: ccd0df2c7da1
Create Date: 2020-12-09 13:10:49.501999

"""
from alembic import op
import sqlalchemy as sa
import sqlalchemy_utils

# revision identifiers, used by Alembic.
revision = 'd5e539d43045'
down_revision = 'ccd0df2c7da1'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('admin_app_token',
    sa.Column('token_id', sa.Integer(), nullable=False),
    sa.Column('token', sqlalchemy_utils.types.encrypted.encrypted_type.EncryptedType(), nullable=True),
    sa.PrimaryKeyConstraint('token_id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('admin_app_token')
    # ### end Alembic commands ###
